#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: settings.py 12425 2020-07-26 06:31:20Z Bear $
#
# Copyright (c) 2014 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Bear $
# $Date: 2020-07-26 14:31:20 +0800 (週日, 26 七月 2020) $
# $Revision: 12425 $

import os
import sys

#============================================================================
# Production or Debug mode.
 
from Iuno import DEVELOPMENT, STAGE, PRODUCTION

SERVER_MODE = PRODUCTION
# Generally, this project should run at PRODUCTION mode, 
import Iuno

# SERVER_MODE = Iuno.detectServerMode(locals())
# DEBUG = Iuno.detectDebug(locals())
#============================================================================

#============================================================================
# Project settings.

APP_NAME = 'mailworker'
APP_VERSION = "0.4.1." + "$Revision: 12425 $"[11:-2]
 
INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.admin',
    'Iuppiter.extension',
    'Iuno.cloud.mail'
)

ROOT_URLCONF = 'mail.urls'
#============================================================================
 
#============================================================================
# Administration. 
ADMINS = (
    ('Bear', 'bear@tracedig.com'),
    ('David', 'david.lee@nuwainfo.com')
)
 
# Make this unique, and don't share it with anybody.
SECRET_KEY = 'a8vca0)a2kvj_dp_egxvo$)1k4wn#l-j3ns61*y!bmxst73f9^'
#============================================================================
 
#============================================================================
# Email.
 
EMAIL_BACKEND = 'Iuno.cloud.mail.EmailBackend'
#============================================================================
 
#============================================================================
# AWS.
AWS_ACCESS_KEY_ID = "AKIAJCORPHHFNLS3OEEA"
AWS_SECRET_ACCESS_KEY = "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"

if SERVER_MODE == DEVELOPMENT:
    pass # Do nothing.
else:
    # http://docs.pythonboto.org/en/latest/boto_config_tut.html
    botoCfg = os.path.abspath(
        os.path.join(os.path.dirname(__file__), '..', '.boto'))
    if not os.path.exists(botoCfg):
        raise RuntimeError('You must setup .boto file to store AWS credentials '
                           'that has SES send authorization.')
    from sys import platform as _platform

    if _platform == "win32":
        os.environ['BOTO_CONFIG'] = botoCfg
    else:
        print (
            "Except for Windows platform, other OS can't apply the boto"
            "settings with the .boto file in project folder,"
            "see http://docs.pythonboto.org/en/latest/boto_config_tut.html"
            "or set it in settings.py yourself."
        )
#============================================================================
 
#============================================================================
# Iuno.cloud.
 
IUNO_CLOUD_ENABLE = True
IUNO_CLOUD_QUEUE_SETTINGS = {
    'preferred': {
        'Nuwa': ('mq.nuwainfo.com',),
    },
}
IUNO_CLOUD_SERVICES = ('queue', 'mail', 'browser') 
# IUNO_CLOUD_LOGGING_SETTINGS = {
#     'project': APP_NAME,
#     #'force': True,
# }
 
IUNO_CLOUD_LOGGING_FILE = os.path.join(os.path.dirname(__file__), 'mail.log')
#============================================================================
ALLOWED_DOMAINS = ['extension.mail', ]

IUNO_SITE_DOMAIN_NAMES = {
    DEVELOPMENT: '', 
    STAGE: '', 
    PRODUCTION: ''
}

BASE_DIR = os.path.dirname(os.path.dirname(__file__))
DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
    }
}

Iuno.attachSettings(locals())


# BROKER_URL = 'amqp://celery:25025529@mq.nuwainfo.com:5672/'
# CELERY_BROKER_URL = 'amqp://celery:25025529@mq.nuwainfo.com:5672/'
# CELERY_RESULT_BACKEND = 'redis://:25025529@mq.nuwainfo.com:6379'
# CELERY_TASK_SERIALIZER = 'pickle'
# CELERY_RESULT_SERIALIZER = 'pickle'
# CELERY_ACCEPT_CONTENT = ['pickle']
# CELERY_TASK_ROUTES = {'Iuno.cloud.mail.tasks.send': {'queue': 'mail'}}
# del CELERY_ROUTES

# CELERY_ROUTES = {'Iuno.cloud.mail.tasks.send': {'queue': 'mail'}}

